@@ -587,7 +587,7 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool, bool hav
   
   packageInfo *ptree;
   QString pkgId =  name;
-//  kDebug() << "pkgId=" << pkgId << "\n";
+  kDebug() << "pkgId=" << pkgId << "\n";
 
   if (haveInstall) {
 	ptree = dirInstPackages.value(pkgId); // remove installed entry
@@ -608,12 +608,12 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool, bool hav
 	  }
 	}
 
-//      dirInstPackages->insert(pkgId,pnew);
+      pki->rmInfo("old-version");
       pki->packageState = packageInfo::INSTALLED;
       q = pki->place(treeList,true);
-//      allPackages.append(pnew);
+
       if (!q) {
-//	kDebug() << "N=" << pki->getInfo("name") << "\n";
+	kDebug() << "N=" << pki->getInfo("name") << "\n";
       } else {
 	treeList->sweep(true);
 	searchLine->updateSearch();
@@ -623,11 +623,11 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool, bool hav
       dirInstPackages.remove(pkgId);
       KpTreeListItem  *qt = pki->getItem();
       if (qt) {
-//	kDebug() << "qt pkgId=" << pkgId << "\n";
+	kDebug() << "qt pkgId=" << pkgId << "\n";
 	treeList->stackRemove(qt);
         treeList->setSelected(qt,false);
 
-// 	kDebug() << "treeList->setSelected(qt,false);" << "\n";
+ 	kDebug() << "treeList->setSelected(qt,false);" << "\n";
 	if (treeList->markPkg == qt)
 	  treeList->markPkg = 0;
 	pki->deleteItem();
@@ -637,7 +637,7 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool, bool hav
    
       packageInfo *pb = dirUninstPackages.value(pkgId);
       if (pb) { // available package matching the one just uninstalled
-//	kDebug() << "pb pkgId=" << pkgId << "\n";
+	kDebug() << "pb pkgId=" << pkgId << "\n";
 	pb->packageState = packageInfo::NEW;
 	dirUninstPackages.insert(pkgId, pb);
 	dirInstPackages.remove(pkgId);
@@ -649,6 +649,18 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool, bool hav
 	  searchLine->updateSearch();
 	  return q;
 	}
+      } else {
+	pki->packageState = packageInfo::NEW;
+	dirUninstPackages.insert(pkgId, pki);
+	q = pki->place(treeList,true);
+	if (!q) {
+	  kDebug() << "NOTP=" << qPrintable(pb->getInfo("name")) << "\n";
+	} else {
+	  treeList->sweep(true);
+	  searchLine->updateSearch();
+	  return q;
+	}
+ 	
       }
   }
 
