@@ -355,7 +355,7 @@ packageInfo *pkgInterface::collectInfo(QStringList &ln, pkgInterface *pkgInt)
     }
     i->packType = pType;
     i->fixup();
-    //  kDebug() << "==" << packName << "\n";
+//      kDebug() << "==" << packName << "\n";
     return i;
   } else {
     return 0;
@@ -363,6 +363,22 @@ packageInfo *pkgInterface::collectInfo(QStringList &ln, pkgInterface *pkgInt)
 }
 
 //////////////////////////////////////////////////////////////////////////////
+void pkgInterface::removeLastEmpty(QStringList &list) 
+{    
+  if (list.count() > 0) {
+    QMutableListIterator<QString> i(list);
+    i.toBack();
+    if (i.peekPrevious().isEmpty()) {
+      i.previous();
+      i.remove();
+    }
+    if (i.peekPrevious().isEmpty()) {    
+      i.previous();
+      i.remove();
+    }
+  }
+  kDebug() << "R1" << list <<"\n"; 
+}
 
 QStringList  pkgInterface::listInstalls(const QStringList &packs, bool install, bool &)
 {
@@ -386,15 +402,12 @@ QStringList  pkgInterface::listInstalls(const QStringList &packs, bool install,
 kDebug() << "L=" << list << "\n";
   if (!kpty->Result) {
 
+    removeLastEmpty(list);
     QMutableListIterator<QString> i(list);
     i.toBack();
-  // rmove last two lines
-    i.previous();
-    i.remove();
-    i.previous();
-    i.remove();
+    kDebug() << "L2=" << list << "\n";
   
-  // Skip non-blank lines (wanted text)
+    // Skip non-blank lines (wanted text)
     while (i.hasPrevious()) {
       if (!i.peekPrevious().isEmpty()) {
        i.previous();
@@ -408,7 +421,8 @@ kDebug() << "L=" << list << "\n";
       i.previous();
       i.remove();
     }
-   
+    kDebug() << "L3=" << list << "\n";
+  
     return list;
   } else {
     return QStringList();
@@ -437,13 +451,9 @@ QStringList pkgInterface::getPackageState( const QStringList &packages)
 //  kDebug() << "s=" << s << "LS=" << list.count()  << "\n";
 //    kDebug() << "Status=" << list << "\n";
  
+  removeLastEmpty(list);
+  
   QMutableListIterator<QString> i(list);
-  i.toBack();
-  // rmove last two lines
-  i.previous();
-  i.remove();
-  i.previous();
-  i.remove();
   
   i.toFront();
   
@@ -489,14 +499,9 @@ void pkgInterface::getPackageDepends(packageInfo *p)
 //          kDebug() << "s=" << s << "LS=" << list.count()  << "\n";
 //          kDebug() << "Status=" << list << "\n";
  
-  QMutableListIterator<QString> i(list);
-  i.toBack();
-  // rmove last two lines
-  i.previous();
-  i.remove();
-  i.previous();
-  i.remove();
+  removeLastEmpty(list);
   
+  QMutableListIterator<QString> i(list);
   i.toFront();
   
   // Remove non-blank lines forward (cache access info)
